#
# spec file for package python-s3transfer
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-s3transfer
Version:        0.10.1
Release:        1.1
Summary:        Python S3 transfer manager
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/boto/s3transfer
Source0:        https://files.pythonhosted.org/packages/source/s/s3transfer/s3transfer-%{version}.tar.gz
BuildRequires:  %{python_module botocore >= 1.33.2}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-requests
Requires:       (python-botocore >= 1.33.2 with python-botocore <= 2.0.0)
BuildArch:      noarch
%if 0%{?sle_version} >= 150400
Obsoletes:      python3-s3transfer < %{version}
%endif
%python_subpackages

%description
A transfer manager for Amazon Web Services S3

%prep
%setup -q -n s3transfer-%{version}
# remove integration tests that need running s3
rm -rf tests/integration

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# test_download_futures_fail_triggers_shutdown - https://github.com/boto/s3transfer/pull/162
%pytest -k 'not test_download_futures_fail_triggers_shutdown'

%files %{python_files}
%license LICENSE.txt
%doc README.rst
%{python_sitelib}/s3transfer/
%{python_sitelib}/s3transfer-%{version}*-info

%changelog
* Fri Apr  5 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.10.1
  * bugfix:``urllib3``: Fixed retry handling for IncompleteRead
    exception raised by urllib3 2.x during data transfer
* Mon Mar  4 2024 Robert Schweikert <rjschwei@suse.com>
- Drop Provides for SLE 15 SP4 and openSUSE Leap 15.4 and later
* Wed Jan 31 2024 Robert Schweikert <rjschwei@suse.com>
- Switch to Python 3.11 build in SLE 15 SP4 and openSUSE Leap 15.4 and
  later (jsc#PCT-371).
- Switch to wheel build
- Update to 0.10.0
  * feature:``s3``: Added CRT support for S3 Express One Zone
- From 0.9.0
  * feature:Python: End of support for Python 3.7
* Mon Dec 11 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update 0.8.2
  * bugfix:Subscribers: Added caching for Subscribers to improve
    throughput by up to 24%% in high volume transfer
- from version 0.8.1
  * enhancement:``s3``: Added support for defaulting checksums
    to CRC32 for s3express.
- from version 0.8.0
  * enhancement:``crt``: Automatically configure CRC32 checksums for
    uploads and checksum validation for downloads through the CRT
    transfer manager.
  * feature:``crt``: S3transfer now supports a wider range of CRT
    functionality for uploads to improve throughput in the CLI/Boto3.
  * enhancement:``Botocore``: S3Transfer now requires Botocore >=1.32.7
  * enhancement:``crt``: Update ``target_throughput`` defaults. If not
    configured, s3transfer will use the AWS CRT to attempt to determine
    a recommended target throughput to use based on the system. If there
    is no recommended throughput, s3transfer now falls back to ten
    gigabits per second.
  * enhancement:``crt``: Add support for uploading and downloading file-like
    objects using CRT transfer manager. It supports both seekable and
    non-seekable file-like objects.
- Update BuildRequires and Requires from setup.py
* Fri Oct  6 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.7.0
  * feature:``SSE-C``: Pass SSECustomer* arguments to
    CompleteMultipartUpload for upload operations
* Fri Sep  1 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.6.2
  * enhancement:Python: Added provisional Python 3.12
    support to s3transfer
* Mon Jul  3 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.6.1
  * bugfix:copy: Added support for ``ChecksumAlgorithm``
    when uploading copy data in parts
* Tue May 30 2023 Dirk Müller <dmueller@suse.com>
- drop no-bundled-packages.patch to allow unpinning urllib3
  boo#1211830
* Wed May 17 2023 Dirk Müller <dmueller@suse.com>
- pin to urllib3 1.x
* Wed Apr  5 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update in SLE-15 (bsc#1209255, jsc#PED-3780)
- Add python-python-dateutil and python-jmespath to BuildRequires
* Thu Nov  3 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update in SLE-15 (bsc#1204537, jsc#PED-2333)
* Fri Jun  3 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.6.0
  * feature:Python: Dropped support for Python 3.6
- from version 0.5.2
  * enhancement:``s3``: Added support for flexible checksums
    when uploading or downloading objects.
- from version 0.5.1
  * enhancement:Python: Officially add Python 3.10 support
- Drop unused python-mock dependency from BuildRequires
- Refresh patches for new version
  + no-bundled-packages.patch
* Tue Jul 27 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update 0.5.0: (bsc#1189649)
  * feature:Python: Dropped support for Python 2.7
- Disable Python2 builds for all SUSE distributions
- Remove Python2 build dependencies from spec file
* Wed May 19 2021 Antonio Larrosa <alarrosa@suse.com>
- Update to 0.4.2:
  * enhancement:s3: Add support for ExpectedBucketOwner. Fixes #181.
- Update to 0.4.1:
  * enhancement:crt: Add set_exception to CRTTransferFuture to allow setting exceptions in subscribers.
- Update to 0.4.0:
  * feature:crt: Add optional AWS Common Runtime (CRT) support. The AWS CRT provides a C-based S3 transfer client that can improve transfer throughput.
- Update to 0.3.7:
  * bugfix:ReadFileChunk: Fix seek behavior in ReadFileChunk class
- Update to 0.3.6:
  * bugfix:packaging: Fix setup.py metadata for futures on Python 2.7
- Update to 0.3.5:
  * enhancement:s3: Block TransferManager methods for S3 Object Lambda resources
* Tue Jan 12 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.3.4:
  * enhancement:s3: Add server side encryption context into allowed list
* Thu Nov 26 2020 Robert Schweikert <rjschwei@suse.com>
- Only build Python3 flavors for distributions 15 and greater
* Fri Apr 10 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update in SLE-15 (bsc#1168943)
* Tue Apr  7 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Fix build on SLE-12
  + Add python to BuildRequires for suse_version < 1500
  + Add python-scandir to BuildRequires for suse_version < 1500
* Fri Mar 13 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Tue Mar 10 2020 Tomáš Chvátal <tchvatal@suse.com>
- Skip test failing on python 3.8, it is race condition that needs
  to be fixed in tests
* Thu Feb 27 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.3.3:
  * bugfix:dependency: Updated botocore version range
- Drop patch hide_py_pckgmgmt.patch it should not be needed
  * we updated setuptools on SLE 12 to handle complex dependencies
- Use pytest for test execution:
  * the nose is used by upstream but really not needed and it
    will get borked with python 3.10
* Mon Jan 27 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.3.2
  * bugfix:s3: Fixes boto/botocore`#1916 <https://github.com/boto/botocore/issues/1916>`__
- from version 0.3.1
  * enhancement:TransferManager: Expose client and config properties
  * enhancement:Tags: Add support for Tagging and TaggingDirective
- from version 0.3.0
  * feature:Python: Dropped support for Python 2.6 and 3.3.
- Refresh patches for new version
  + hide_py_pckgmgmt.patch
* Thu Aug 22 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update in SLE-15 (bsc#1146854)
* Wed Jun 12 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.2.1 (bsc#1146853)
  * enhancment:ProcessPool: Adds user agent suffix.
* Wed Feb 13 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.2.0
  * feature:``ProcessPoolDownloader``: Add ``ProcessPoolDownloader`` class
    to speed up download throughput by using processes instead of threads.
- Drop obsolete patch
  + system-requests.patch
- Refresh patches for new version
  + hide_py_pckgmgmt.patch
  + no-bundled-packages.patch
- Update Requires in spec file from setup.py
* Wed May  9 2018 tchvatal@suse.com
- Avoid running tests on 32bit as they fail there on oom
* Tue May  8 2018 tchvatal@suse.com
- Make sure to really not use any damn bundles:
  * no-bundled-packages.patch
  * Never rely on some bundled package version just use system libs
- Enable testsuite and make it pass thanks to above patch
* Thu Apr 19 2018 mimi.vx@gmail.com
- update to 0.1.13 (bsc#1075263)
- add system-requests.patch - use system python-requests
  * Plumb ``RequestPayer` argument to the ``CompleteMultipartUpload` operation
  * enhancement:max_bandwidth: Add ability to set maximum bandwidth consumption
  for streaming of S3 uploads and downloads
* Thu Nov  9 2017 rjschwei@suse.com
- Update to version 0.1.11:
  + Properly handle unicode exceptions in the context manager
* Thu May 11 2017 toddrme2178@gmail.com
- Implement single-spec version.
- Update source URL.
* Thu Jan 19 2017 dmueller@suse.com
- use pypi.io
* Wed Jan 18 2017 astieger@suse.com
- update to 0.1.10:
  * feature: TransferManager: Expose ability to use own executor
    class for TransferManager
  * fix factory submission (validate source)
* Wed Oct 26 2016 rjschwei@suse.com
- Update to version 0.1.9 (bsc#1007084)
  + Forward port hide_py_pckgmgmt.patch
  + No changelog entry for 0.1.9
- From 0.1.8
  + feature:download: Support downloading to FIFOs.
- From 0.1.7
  + bugfix:TransferManager: Fix memory leak when using same client to create
    multiple TransferManagers
- From 0.1.6
  + bugfix:download: Fix issue where S3 Object was not downloaded to disk
    when empty
- From 0.1.5
  + bugfix:Cntrl-C: Fix issue of hangs when Cntrl-C happens for many queued
    transfers
  + feature:cancel: Expose messages for cancels
- from 0.1.4
  + feature:chunksize: Automatically adjust the chunksize if it doesn't meet
    S3s requirements.
  + bugfix:Download: Add support for downloading to special UNIX file by name
- From 0.1.3
  + feature:delete: Add a .delete() method to the transfer manager.
  + bugfix:seekable upload: Fix issue where seeked position of seekable
    file for a nonmultipart upload was not being taken into account.
- From 0.1.2
  + bugfix:download: Patch memory leak related to unnecessarily holding
    onto futures for downloads.
- From 0.1.1
  + bugfix:deadlock: Fix deadlock issue described here:
    https://bugs.python.org/issue20319 with using concurrent.futures.wait
- From 0.1.0
  + feature:copy: Add support for managed copies.
  + feature:download: Add support for downloading to a filename, seekable
    file-like object, and nonseekable file-like object.
  + feature:general: Add TransferManager class. All public functionality
    for s3transfer is exposed through this class.
  + feature:subscribers: Add subscriber interface. Currently supports
    on_queued, on_progress, and on_done status changes.
  + feature:upload: Add support for uploading a filename, seekable file-like
    object, and nonseekable file-like object.
* Mon Apr 18 2016 rjschwei@suse.com
- Include in SLE 12 (FATE#320748, bsc#974993, bsc#975949)
* Tue Apr 12 2016 rjschwei@suse.com
- Set the proper target directory for copying the license file
  + Fixes build issue on SLE 11
* Mon Apr 11 2016 rjschwei@suse.com
- Initial build
  + Version 0.0.1
